#!/usr/bin/env python
# coding: utf-8

# In[7]:


get_ipython().run_line_magic('load_ext', 'nb_black')
get_ipython().run_line_magic('load_ext', 'autoreload')
get_ipython().run_line_magic('autoreload', '2')

import os
import pathlib
import glob
import naaqs_fires_analysis
import numpy as np
import pandas as pd


# In[9]:


# read in and preprocess monitor location data

all_monitors_df = pd.read_csv(
    "C:\\Users\\RRice\\OneDrive - Environmental Protection Agency (EPA)\\naaqs-fires data\\raw aqs data\\aqs_monitors.csv",
    low_memory=False,
)
all_monitors_df["Last Sample Date"] = pd.to_datetime(
    all_monitors_df["Last Sample Date"]
)

all_monitors_df = all_monitors_df[
    (all_monitors_df["Last Sample Date"] >= "2006-01-01")
    & (all_monitors_df["State Code"] == "06")
]

all_monitors_df = all_monitors_df[
    all_monitors_df["Parameter Name"].str.contains("PM2.5 LC")
]
all_monitors_df.set_index(
    ["State Code", "County Code", "Site Number", "POC"], inplace=True
)
all_monitors_df = all_monitors_df[~all_monitors_df.index.duplicated()]


# In[14]:


# create a dataframe with a row for each date for each monitor

date_dfs = []

dates = pd.date_range("2006-01-01", "2018-12-31")

for date in dates:
    date_df = all_monitors_df.copy()
    date_df["Date Local"] = date
    date_dfs.append(date_df)

all_monitor_dates_df = pd.concat(date_dfs)


# In[15]:


# create GIS dataset of monitor locations

import geopandas

# get aqs data into geopandas
nad83 = all_monitor_dates_df[all_monitor_dates_df.Datum == "NAD83"]
wgs84 = all_monitor_dates_df[all_monitor_dates_df.Datum == "WGS84"]

# make geopandas dataframes with appropriate crs
nad83_gdf = geopandas.GeoDataFrame(
    nad83,
    geometry=geopandas.points_from_xy(nad83.Longitude, nad83.Latitude),
    crs="EPSG:4269",
)
wgs84_gdf = geopandas.GeoDataFrame(
    wgs84,
    geometry=geopandas.points_from_xy(wgs84.Longitude, wgs84.Latitude),
    crs="EPSG:4326",
)

# reproject nad83 to wgs84
nad83_gdf.to_crs("EPSG:4326", inplace=True)

# recombine datasets
aqs_gdf = pd.concat([nad83_gdf, wgs84_gdf], ignore_index=True).drop(columns="Datum")

# create year column
aqs_gdf["year"] = aqs_gdf["Date Local"].dt.year


# In[16]:


aqs_gdf.head()


# In[19]:


def run_fire_analysis(hms_fire_folder, aqs_data, dest_folder="output"):

    for year in range(2006, 2019):

        # get lists of files for year of analysis:

        hms_fire_year = pathlib.Path(hms_fire_folder).glob(f"*{year}*.shp")

        aqs_data_year = aqs_data.loc[aqs_data.year == year]

        # Load geopandas dataframe of hms fire polygon shapefiles
        fire_df = naaqs_fires_analysis.preprocess_fire_points(hms_fire_year)

        # split AQS daily data into smaller chunks for streaming of analysis
        for i, aqs_data_i in enumerate(np.array_split(aqs_data_year, 100)):

            dest_path = os.path.join(
                dest_folder, f"aqs_spec_fire_output_{year}_{i}.pkl"
            )

            if not os.path.exists(dest_path):

                # Check if AQS falls within fire plume on day
                fire_analysis = naaqs_fires_analysis.distance_to_nearest_fire(
                    aqs_gdf=aqs_data_i, fire_points_gdf=fire_df
                )

                # export to pickle
                fire_analysis.to_pickle(dest_path)


# In[20]:


# paths to data

hms_fire_folder = "C:\\Users\\RRice\\OneDrive - Environmental Protection Agency (EPA)\\naaqs-fires data\\raw_noaa_hms_data\\2006-2019_hms_fires"


# In[21]:


run_fire_analysis(hms_fire_folder, aqs_gdf, dest_folder="fire_output_ca")


# In[3]:


output = pd.concat(
    [pd.read_pickle("fire_output_ca/" + x) for x in os.listdir("fire_output_ca")]
)


# In[31]:


merge_columns = [
    "Parameter Code",
    "Parameter Name",
    "Latitude",
    "Longitude",
    "First Year of Data",
    "Last Sample Date",
    "Monitor Type",
    "Networks",
    "Reporting Agency",
    "PQAO",
    "Collecting Agency",
    "Exclusions",
    "Monitoring Objective",
    "Last Method Code",
    "Last Method",
    "Measurement Scale",
    "Measurement Scale Definition",
    "NAAQS Primary Monitor",
    "QA Primary Monitor",
    "Local Site Name",
    "Address",
    "State Name",
    "County Name",
    "City Name",
    "CBSA Name",
    "Tribe Name",
    "Extraction Date",
]

output = output.reset_index().merge(all_monitors_df.reset_index(), on=merge_columns)


# In[32]:


output.to_csv(
    "california AQS speciation monitors distance to closest fire 2006-2018.csv",
    index=True,
)


# In[ ]:




