# -*- coding: utf-8 -*-
"""
Created on Mon Nov 29 10:52:47 2021

@author: KBOAGGIO
"""
import pandas as pd
import os
os.chdir('C:\\Users\\KBoaggio\\OneDrive - Environmental Protection Agency (EPA)\\Wildfire data\\Final files for submission')
import functions

#%% Import and format the data

# Import linked speciation/smoke plume data
pm_spec = pd.read_csv('2006-2018_pm_speciation_labeled_joined_pm_11_3_21.csv')
pm_spec['Date'] = pd.to_datetime(pm_spec['Date'])
pm_spec = pm_spec.reset_index().set_index(['Date', 'State Code', 'County Code', 'Site Number', 'POC'])
pm_spec = pm_spec[~pm_spec.index.get_level_values(0).month.isin([1, 2, 3])] # Cut down data to April-December only
pm_spec['Arithmetic Mean'] = pm_spec['Arithmetic Mean'].astype(float) # Change data type for analysis

# Split the speciation data into fire and non-fire and create column for year
spec_fire_tot = pm_spec[(pm_spec['in_smoke?'] == 1)]
spec_no_fire_tot = pm_spec[pm_spec['in_smoke?'] != 1]
spec_fire_tot['Type'] = 'Fire'
spec_no_fire_tot['Type'] = 'No Fire'
spec_fire_tot['Year'] = pd.DatetimeIndex(spec_fire_tot.index.get_level_values('Date')).year
spec_no_fire_tot['Year'] = pd.DatetimeIndex(spec_no_fire_tot.index.get_level_values('Date')).year
pm_spec_added_col = pd.concat([spec_fire_tot, spec_no_fire_tot])

# Take average for each station separately for each year
fire_mean, nofire_mean, percent_diff, pd_avg, sm = functions.stations(spec_fire_tot, spec_no_fire_tot)

#%% Save data for permutation test in R

pm_spec_perm = pm_spec_added_col #.iloc[:, 0:24]
pm_spec_perm.reset_index(inplace=True)
pm_spec_perm.to_csv('2006-2018_pm_speciation_labeled_new_11_3_21.csv')

#%% Count number of measurements of zero for Supplementary Table 2

non_zeros = functions.count(spec_fire_tot, spec_no_fire_tot)
non_zeros.to_csv('non_zero_values_11_3.csv')

#%% Get median and max % difference, and max concentration difference for Table 1

diffs = percent_diff.reset_index().set_index(['Parameter Name'])
median_percent = diffs.groupby(diffs.index)['Percentage'].apply(lambda x: x.median())
max_diff = diffs.groupby(diffs.index)['Arithmetic Mean'].apply(lambda x: x.max())
max_percent = diffs.groupby(diffs.index)['Percentage'].apply(lambda x: x.max())

diffss = pd.concat([median_percent, max_diff, max_percent], axis=1)
diffss.columns = ['Median % Change', 'Max Conc. Diff', 'Max % Change']
diffss.to_csv('differences_for_table_1.csv')

#%% Potassium:Lead ratio - Supplementary Figure 3

dates = [('2008-06-26'), ('2015-09-12'), ('2018-07-28'), ('2018-07-31'), ('2017-10-10'),  ('2018-11-10'), ('2018-11-16')]
spec_fire_tot = spec_fire_tot.reset_index().set_index('Date')
cut_data = spec_fire_tot.loc[dates]

cut_data = cut_data.reset_index().set_index(['Date', 'State Code', 'County Code', 'Site Number', 'POC'])
cut_data = cut_data[(cut_data['Parameter Name'] == 'Potassium PM2.5 LC') | (cut_data['Parameter Name'] == 'Lead PM2.5 LC') | (cut_data['Parameter Name'] == 'Copper PM2.5 LC')]

cut_data['Ratio'] = (cut_data[cut_data['Parameter Name'] == 'Lead PM2.5 LC']['Arithmetic Mean'] + cut_data[cut_data['Parameter Name'] == 'Copper PM2.5 LC']['Arithmetic Mean'])/cut_data[cut_data['Parameter Name'] == 'Potassium PM2.5 LC']['Arithmetic Mean']
stations = [(6,67,6,5), (6,105,9000,1), (6,89,3003,1), (6,93,5,1), (6,7,8,5),(6,41,2,1), (6,85,5,5), (6,19,11,5), (6,19,11,1), (6,69,3,1), (6,43,3,1), (6,43,3,2), (6,99,5,5)]
cut_data = cut_data.reset_index().set_index(['State Code', 'County Code', 'Site Number', 'POC'])
cut_math = cut_data.loc[stations]
cut_math = cut_math.reset_index().set_index(['Date','Local Site Name'])


