# -*- coding: utf-8 -*-
"""
Created on Mon Nov 29 11:07:40 2021

@author: KBOAGGIO
"""
import pandas as pd
import matplotlib.pyplot as plt
from scipy import stats
import os
os.chdir('C:\\Users\\KBoaggio\\OneDrive - Environmental Protection Agency (EPA)\\Wildfire data\\Final files for submission')
import numpy as np
import sklearn.preprocessing
from mpl_toolkits.basemap import Basemap
import functions
import matplotlib.ticker

#%% Import and format the data

# Import linked speciation/smoke plume data
pm_spec = pd.read_csv('2006-2018_pm_speciation_labeled_joined_pm_11_3_21.csv')
pm_spec['Date'] = pd.to_datetime(pm_spec['Date'])
pm_spec = pm_spec.reset_index().set_index(['Date', 'State Code', 'County Code', 'Site Number', 'POC'])
pm_spec = pm_spec[~pm_spec.index.get_level_values(0).month.isin([1, 2, 3])] # Cut down data to April-December only
pm_spec['Arithmetic Mean'] = pm_spec['Arithmetic Mean'].astype(float) # Change data type for analysis

# Split the speciation data into fire and non-fire and create column for year
spec_fire_tot = pm_spec[(pm_spec['in_smoke?'] == 1)]
spec_no_fire_tot = pm_spec[pm_spec['in_smoke?'] != 1]
spec_fire_tot['Type'] = 'Fire'
spec_no_fire_tot['Type'] = 'No Fire'
spec_fire_tot['Year'] = pd.DatetimeIndex(spec_fire_tot.index.get_level_values('Date')).year
spec_no_fire_tot['Year'] = pd.DatetimeIndex(spec_no_fire_tot.index.get_level_values('Date')).year
pm_spec_added_col = pd.concat([spec_fire_tot, spec_no_fire_tot])

# Take average for each station separately for each year
fire_mean, nofire_mean, percent_diff, pd_avg, sm = functions.stations(spec_fire_tot, spec_no_fire_tot)

#%% Figure 1: plot stations

# Create different variables for stations, IMPROVE, and CSN
stations = pm_spec.reset_index().set_index(['State Code', 'County Code', 'Site Number', 'POC'])
stations = stations[~stations.index.duplicated()]
stations = stations.reset_index().set_index(['State Code', 'County Code', 'Site Number'])
improve = stations.loc[stations['Method Name'].str.contains("IMPROVE")]
csn = stations.loc[stations['Method Name'].str.contains("Met")]
both = improve[improve.index.isin(csn.index.values)]

# Plot specific to California 
fig = plt.figure(figsize=(8, 8))
m = Basemap(projection='lcc', resolution='l', 
            lat_0=37.5, lon_0=-119,
            width=1E6, height=1.2E6)
#m.shadedrelief()
m.drawlsmask(land_color='w', ocean_color='skyblue')
m.drawcoastlines(color='gray')
m.drawcountries(color='gray')
m.drawstates(color='gray')

# Create points for specific major CA cities
x,y = m(-118.244, 34.052) # LA
x2,y2 = m(-117.165, 32.716) # SD
x3,y3 = m(-121.895, 37.339) # SJ
x4,y4 = m(-122.419, 37.775) # SF
x5,y5 = m(-119.772, 36.748) # Fresno
x6,y6 = m(-121.494, 38.582) # Sac

# Scatter locations of monitoring sites and major cities and label cities
m.scatter(x,y, marker='*', c='black', s=80)
m.scatter(x2,y2, marker='*', c='black', s=80)
m.scatter(x3,y3, marker='*', c='black', s=80)
m.scatter(x4,y4, marker='*', c='black', s=80)
m.scatter(x5,y5, marker='*', c='black', s=80)
m.scatter(x6,y6, marker='*', c='black', s=80)
m.scatter(improve['Longitude'].to_numpy(), improve['Latitude'].to_numpy(), latlon=True, c='g', s=15, label="IMPROVE")
m.scatter(csn['Longitude'].to_numpy(), csn['Latitude'].to_numpy(), latlon=True, c='purple', s=15, label="CSN")
m.scatter(both['Longitude'].to_numpy(), both['Latitude'].to_numpy(), latlon=True, c='lightblue', s=15, label="Both")
plt.text(x, y, 'Los Angeles',fontsize=10,fontweight='bold',
                    ha='right',va='top',color='k')
plt.text(x2, y2, 'San Diego',fontsize=10,fontweight='bold',
                    ha='right',va='top',color='k')
plt.text(x3, y3, 'San Jose',fontsize=10,fontweight='bold',
                    ha='right',va='top',color='k')    
plt.text(x4, y4, 'San Francisco',fontsize=10,fontweight='bold',
                    ha='right',va='bottom',color='k')
plt.text(x5, y5, 'Fresno',fontsize=10,fontweight='bold',
                    ha='left',va='bottom',color='k')
plt.text(x6, y6, 'Sacramento',fontsize=10,fontweight='bold',
                    ha='left',va='bottom',color='k')
plt.legend(fontsize='xx-large')
#plt.show()
plt.savefig("lead_stations_11_3_21.png", dpi=300, bbox_inches='tight')

#%% Figure 2: Plot average percent differences of all years for each element box plot 

# Change spec_list and xlabels for the two parts of Figure 2
#spec_list = ['Potassium PM2.5 LC','Bromine PM2.5 LC','Manganese PM2.5 LC','Calcium PM2.5 LC','Titanium PM2.5 LC','Aluminum PM2.5 LC','Silicon PM2.5 LC','Iron PM2.5 LC','Sulfate PM2.5 LC', 'Sulfur PM2.5 LC','Vanadium PM2.5 LC','Sodium PM2.5 LC','Zinc PM2.5 LC','Copper PM2.5 LC','Zirconium PM2.5 LC','Magnesium PM2.5 LC','Strontium PM2.5 LC','Rubidium PM2.5 LC','Lead PM2.5 LC','Phosphorus PM2.5 LC']
spec_list = ['Yttrium PM2.5 LC','Mercury PM2.5 LC','Antimony PM2.5 LC','Cobalt PM2.5 LC','Selenium PM2.5 LC','Tin PM2.5 LC','Molybdenum PM2.5 LC','Barium PM2.5 LC','Total Nitrate PM2.5 LC','Nickel PM2.5 LC','Chloride PM2.5 LC','Ammonium Ion PM2.5 LC','Indium PM2.5 LC','Chlorine PM2.5 LC','Chromium PM2.5 LC','Cesium PM2.5 LC','Cadmium PM2.5 LC','Arsenic PM2.5 LC','Silver PM2.5 LC','Cerium PM2.5 LC']

#xlabels = ['Potassium','Bromine','Manganese','Calcium','Titanium','Aluminum','Silicon','Iron','Sulfate', 'Sulfur','Vanadium','Sodium','Zinc','Copper','Zirconium','Magnesium','Strontium','Rubidium','Lead','Phosphorus']
xlabels = ['Yttrium','Mercury','Antimony','Cobalt','Selenium','Tin','Molybdenum','Barium','Total Nitrate','Nickel','Chloride','Ammonium','Indium','Chlorine','Chromium','Cesium','Cadmium','Arsenic','Silver','Cerium']

# Cut down data to specific PM species and columns
fire_days = percent_diff.reset_index()
fire_days = fire_days.set_index('Parameter Name')
fire_days = fire_days.loc[spec_list, ['Percentage', 'Year', 'State Code', 'County Code', 'Site Number']]
fire_days = fire_days.reset_index()

# Grab percentage differences for all species and concatenate 
percentdiff = []
for i in spec_list:
    percenty = fire_days.reset_index().set_index(['State Code', 'County Code', 'Site Number','Year'])
    percenty = percenty[percenty['Parameter Name'] == i]
    percentdiff.append(percenty['Percentage']) #or Percentage

# Create function to plot percent differences for all stations and years
plt.rcParams['font.size']=18
def draw_plot2(data, offset, edge_color, fill_color):
    pos = np.arange(0,20)+offset 
    flierprops = dict(marker='o', markerfacecolor=edge_color, markersize=4,
                  linestyle='', markeredgecolor=edge_color)
    meanpointprops = dict(marker='D', markeredgecolor='black',
                      markerfacecolor='firebrick')
    #ax0 = plt.subplot2grid((5,1), (0, 0))
    #bp = ax0.boxplot(data, positions= pos, widths=0.3, manage_xticks=False, flierprops=flierprops, showmeans=True, meanprops=meanpointprops, meanline= False)
    ax1 = plt.subplot2grid((5,1), (0, 0), rowspan=4) #, sharex = ax0)
    ax1.boxplot(data, positions= pos, widths=0.3, manage_xticks=False, flierprops=flierprops, showmeans=True, meanprops=meanpointprops, meanline= False)
    #ax0.set_ylim(2930,15000)
    #ax1.set_ylim(-150,2700)
    ax1.set_yscale('symlog', linthreshy=1, subsy = [2, 4, 6, 8])
    ax1.get_yaxis().set_major_formatter(matplotlib.ticker.FuncFormatter(lambda x, p: format(int(x), ',')))
    #ax0.yaxis.set_major_locator(plt.MaxNLocator(1))
    #ax0.spines['bottom'].set_visible(False)
    ax1.spines['top'].set_visible(True)
    ax1.xaxis.tick_top()
    #ax0.tick_params(labeltop=False)  # don't put tick labels at the top
    ax1.xaxis.tick_bottom()
    plt.ylabel('Difference in Chemical Concentrations \n on Smoke Days Compared to Non-smoke Days (%) \n') # 'Percentage Change on Fire Days')
    # for element in ['boxes', 'whiskers', 'fliers', 'medians', 'caps']:
    #     plt.setp(bp[element], color=fill_color)
        
    # # For plot break diagonal lines
    # d = .012  # how big to make the diagonal lines in axes coordinates
    # # arguments to pass to plot, just so we don't keep repeating them
    # kwargs = dict(transform=ax0.transAxes, color='k', clip_on=False)
    # ax0.plot((-d, +d), (-d, +d), **kwargs)        # top-left diagonal
    # ax0.plot((1 - d, 1 + d), (-d, +d), **kwargs)  # top-right diagonal
    # kwargs.update(transform=ax1.transAxes)  # switch to the bottom axes
    # ax1.plot((-d, +d), (1 - d/4, 1+ d/4), **kwargs)  # bottom-left diagonal
    # ax1.plot((1 - d, 1 + d), (1 - d/4, 1 + d/4), **kwargs)  # bottom-right diagonal
 
# Plot percent differences for all stations and years for each element    
fig, ax = plt.subplots(figsize=(10,12))
draw_plot2(percentdiff, 0, "black", "black")
plt.axhline(y=0, color = 'k', linestyle ='-', linewidth=1)
plt.xticks(range(0,20), labels=xlabels, rotation = 45, ha='right')
plt.savefig('fig4_part2_new_3_21.png', bbox_inches='tight', dpi=300)

#%% Figure 3 & Supplementary Figure 2: Plot station box plots for each element with axis break
#       - this was used for the plots WITH breaks

# Create the labels and cut down the data by specific element for plotting
labels = [2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018]
percentdiff = []

# Drop NAs and cut down to specific element only
for i in labels:
    percenty = percent_diff.reset_index().set_index(['State Code', 'County Code', 'Site Number', 'POC', 'Parameter Name'])
    percenty = percenty[percenty['Year'] == i].dropna()
    percentdiff.append(percenty.xs('Zirconium PM2.5 LC', level=4, drop_level=False)['Percentage']) #or Arithmetic Mean if plotting the concentration differences

# Create function to plot the concentration differences or percentage differences across all stations as a boxplot
# for each element across all the years
plt.rcParams['font.size']=23
def draw_plot2(data, offset,edge_color, fill_color):
    pos = np.arange(0,13)+offset 
    flierprops = dict(marker='o', markerfacecolor=edge_color, markersize=6,
                  linestyle='', markeredgecolor=edge_color)
    meanpointprops = dict(marker='D', markeredgecolor='black',
                      markerfacecolor='firebrick')
    ax0 = plt.subplot2grid((6, 1), (0, 0))
    bp = ax0.boxplot(data, positions= pos, widths=0.3, manage_xticks=False, flierprops=flierprops, showmeans=True, meanprops=meanpointprops, meanline= False)
    ax1 = plt.subplot2grid((6, 1), (1, 0), rowspan=5, sharex = ax0)
    ax1.boxplot(data, positions= pos, widths=0.3, manage_xticks=False, flierprops=flierprops, showmeans=True, meanprops=meanpointprops, meanline= False)
    ax0.set_ylim(2350,2450)  # Need to change for each specific element/concentration differences
    ax1.set_ylim(-150, 800)  # Need to change for each specific element/concentration differences
    ax0.yaxis.set_major_locator(plt.MaxNLocator(1))
    ax0.spines['bottom'].set_visible(False)
    ax1.spines['top'].set_visible(False)
    ax0.xaxis.tick_top()
    ax0.tick_params(labeltop=False)  # don't put tick labels at the top
    ax1.xaxis.tick_bottom()
    plt.ylabel('Percentage Difference (%)')
    ax1.yaxis.set_label_coords(-0.15, 0.65)

#   plt.ylabel('Percentage Difference (%)')  # or Concentration Difference (ug/m^3) 'Change on Smoke Days (%)'
    for element in ['boxes', 'whiskers', 'fliers', 'medians', 'caps']:
        plt.setp(bp[element], color=fill_color)
        
    # For plot break diagonal lines
    d = .012  # how big to make the diagonal lines in axes coordinates
    # arguments to pass to plot, just so we don't keep repeating them
    kwargs = dict(transform=ax0.transAxes, color='k', clip_on=False)
    ax0.plot((-d, +d), (-d, +d), **kwargs)        # top-left diagonal
    ax0.plot((1 - d, 1 + d), (-d, +d), **kwargs)  # top-right diagonal
    kwargs.update(transform=ax1.transAxes)  # switch to the bottom axes
    ax1.plot((-d, +d), (1 - d/4, 1+ d/4), **kwargs)  # bottom-left diagonal
    ax1.plot((1 - d, 1 + d), (1 - d/4, 1 + d/4), **kwargs)  # bottom-right diagonal
 
fig, ax = plt.subplots(figsize=(10,12))
draw_plot2(percentdiff, 0, "black", "black")
plt.axhline(y=0, color = 'k', linestyle ='-', linewidth=1)
plt.xticks(range(0,13), labels=labels, rotation = 45)
plt.savefig('zirconium_perc_updated_1_13.png', bbox_inches='tight', dpi=300)

#%% Figure 3 & Supplementary Figure 2: Plot percentage without break - with loop for all elements

# Create plot labels and list of elements to run through
labels = [2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018]
params = ['Ammonium Ion PM2.5 LC', 'Antimony PM2.5 LC', 'Aluminum PM2.5 LC', 'Cerium PM2.5 LC', 'Arsenic PM2.5 LC', 'Barium PM2.5 LC', 'Bromine PM2.5 LC', 'Calcium PM2.5 LC', 'Cadmium PM2.5 LC', 'Cesium PM2.5 LC', 'Chromium PM2.5 LC', 'Cobalt PM2.5 LC', 'Copper PM2.5 LC', 'Chloride PM2.5 LC', 'Chlorine PM2.5 LC', 'Indium PM2.5 LC', 'Iron PM2.5 LC', 'Lead PM2.5 LC', 'Magnesium PM2.5 LC',  'Manganese PM2.5 LC', 'Mercury PM2.5 LC', 'Molybdenum PM2.5 LC', 'Nickel PM2.5 LC', 'Phosphorus PM2.5 LC', 'Potassium PM2.5 LC', 'Rubidium PM2.5 LC', 'Selenium PM2.5 LC', 'Silicon PM2.5 LC', 'Silver PM2.5 LC', 'Sodium PM2.5 LC', 'Strontium PM2.5 LC', 'Sulfate PM2.5 LC', 'Sulfur PM2.5 LC', 'Tin PM2.5 LC', 'Titanium PM2.5 LC', 'Total Nitrate PM2.5 LC', 'Vanadium PM2.5 LC', 'Yttrium PM2.5 LC', 'Zinc PM2.5 LC', 'Zirconium PM2.5 LC']

plt.rcParams['font.size']=23
def draw_plot2(data, offset,edge_color,fill_color):
        pos = np.arange(0,13)+offset 
        flierprops = dict(marker='o', markerfacecolor=edge_color, markersize=6,
                      linestyle='', markeredgecolor=edge_color)
        meanpointprops = dict(marker='D', markeredgecolor='black',
                          markerfacecolor='firebrick')
        ax = plt.subplot2grid((6,1), (0,0), rowspan=6)
        bp = ax.boxplot(data, positions= pos, widths=0.3, manage_xticks=False, flierprops=flierprops, showmeans=True, meanprops=meanpointprops, meanline= False)
        plt.ylabel('Concentration Difference (ug/m^3)')
        plt.yscale('symlog', linthreshy=0.01, subsy = [2, 4, 6, 8])
        ax.get_yaxis().set_major_formatter(matplotlib.ticker.FuncFormatter(lambda x, p: "{:.3f}".format(x, ',')))
        for element in ['boxes', 'whiskers', 'fliers', 'medians', 'caps']:
            plt.setp(bp[element], color=fill_color)

for j in params:
    percentdiff = []
    for i in labels:
        percenty = percent_diff.reset_index().set_index(['State Code', 'County Code', 'Site Number', 'POC', 'Parameter Name'])
        percenty = percenty[percenty['Year'] == i].dropna()
        percentdiff.append(percenty.xs(j, level=4, drop_level=False)['Arithmetic Mean'])
    
    fig, ax = plt.subplots(figsize=(10,12))
    draw_plot2(percentdiff, 0, "black", "black")
    plt.xticks(range(0,13), labels=labels, rotation = 45)
    plt.axhline(y=0, color = 'k', linestyle ='-', linewidth=1)
    #plt.yscale('symlog')
    plt.savefig(j+'_conc_test_3_22.png', bbox_inches='tight', dpi=300)
    plt.close()
  
#%% Figure 3 & Supplementary Figure 2: Plot station box plots for each element - with loop for all elements

# Create plot labels and list of elements to run through
labels = [2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018]
params = ['Zirconium PM2.5 LC']
#params = ['Ammonium Ion PM2.5 LC', 'Antimony PM2.5 LC', 'Aluminum PM2.5 LC', 'Arsenic PM2.5 LC', 'Barium PM2.5 LC', 'Bromine PM2.5 LC', 'Calcium PM2.5 LC', 'Cadmium PM2.5 LC', 'Cesium PM2.5 LC', 'Chromium PM2.5 LC', 'Cobalt PM2.5 LC', 'Copper PM2.5 LC', 'Chloride PM2.5 LC', 'Chlorine PM2.5 LC', 'Indium PM2.5 LC', 'Iron PM2.5 LC', 'Lead PM2.5 LC', 'Magnesium PM2.5 LC',  'Manganese PM2.5 LC', 'Mercury PM2.5 LC', 'Molybdenum PM2.5 LC', 'Nickel PM2.5 LC', 'Phosphorus PM2.5 LC', 'Potassium PM2.5 LC', 'Rubidium PM2.5 LC', 'Selenium PM2.5 LC', 'Silicon PM2.5 LC', 'Silver PM2.5 LC', 'Sodium PM2.5 LC', 'Strontium PM2.5 LC', 'Sulfate PM2.5 LC', 'Sulfur PM2.5 LC', 'Tin PM2.5 LC', 'Titanium PM2.5 LC', 'Total Nitrate PM2.5 LC', 'Vanadium PM2.5 LC', 'Yttrium PM2.5 LC', 'Zinc PM2.5 LC', 'Zirconium PM2.5 LC']

plt.rcParams['font.size']=23
def draw_plot2(data, offset,edge_color,fill_color):
    pos = np.arange(0,13)+offset 
    flierprops = dict(marker='o', markerfacecolor=edge_color, markersize=6,
                  linestyle='', markeredgecolor=edge_color)
    meanpointprops = dict(marker='D', markeredgecolor='black',
                      markerfacecolor='firebrick')
    ax = plt.subplot2grid((6,1), (0,0), rowspan=6)
    bp = ax.boxplot(data, positions= pos, widths=0.3, manage_xticks=False, flierprops=flierprops, showmeans=True, meanprops=meanpointprops, meanline= False)
    plt.ylabel('Concentration Difference (ug/m^3)')
    plt.axhline(y=0, color = 'k', linestyle ='-', linewidth=1)
    for element in ['boxes', 'whiskers', 'fliers', 'medians', 'caps']:
        plt.setp(bp[element], color=fill_color)

for k in params:
    percentdiff = []
    for i in labels:
        percenty = percent_diff.reset_index().set_index(['State Code', 'County Code', 'Site Number', 'POC', 'Parameter Name'])
        percenty = percenty[percenty['Year'] == i].dropna()
        percentdiff.append(percenty.xs(k, level=4, drop_level=False)['Arithmetic Mean'])
    fig, ax = plt.subplots(figsize=(10,12))
    draw_plot2(percentdiff, 0, "black", "black")
    plt.xticks(range(0,13), labels=labels, rotation = 45)
    plt.savefig(k+'concentration_final_1_13.png', bbox_inches='tight', dpi=300)
    #plt.show()

#%% Figure 5: Plot the PM2.5 vs. lead concentrations

params = ['Ammonium Ion PM2.5 LC', 'Antimony PM2.5 LC', 'Aluminum PM2.5 LC', 'Arsenic PM2.5 LC', 'Barium PM2.5 LC', 'Bromine PM2.5 LC', 'Calcium PM2.5 LC', 'Cadmium PM2.5 LC', 'Cesium PM2.5 LC', 'Chromium PM2.5 LC', 'Cobalt PM2.5 LC', 'Copper PM2.5 LC', 'Chloride PM2.5 LC', 'Chlorine PM2.5 LC', 'Indium PM2.5 LC', 'Iron PM2.5 LC', 'Lead PM2.5 LC', 'Magnesium PM2.5 LC',  'Manganese PM2.5 LC', 'Mercury PM2.5 LC', 'Molybdenum PM2.5 LC', 'Nickel PM2.5 LC', 'Phosphorus PM2.5 LC', 'Potassium PM2.5 LC', 'Rubidium PM2.5 LC', 'Selenium PM2.5 LC', 'Silicon PM2.5 LC', 'Silver PM2.5 LC', 'Sodium PM2.5 LC', 'Strontium PM2.5 LC', 'Sulfate PM2.5 LC', 'Sulfur PM2.5 LC', 'Tin PM2.5 LC', 'Titanium PM2.5 LC', 'Total Nitrate PM2.5 LC', 'Vanadium PM2.5 LC', 'Yttrium PM2.5 LC', 'Zinc PM2.5 LC', 'Zirconium PM2.5 LC']

# Concatenate the fire and non-fire days
data = pd.concat([spec_fire_tot, spec_no_fire_tot])
data = data.reset_index().set_index(['State Code', 'County Code', 'Site Number', 'POC', 'Year', 'Parameter Name'])
 
# Take the robust scaled normalization of each data point and then cut down the data to just the fire days
data['zscore'] = data.groupby(data.index)['Arithmetic Mean'].transform(lambda x: sklearn.preprocessing.robust_scale(x))
data['zscore_pm'] = data.groupby(data.index)['Arithmetic Mean_pm'].transform(lambda x: sklearn.preprocessing.robust_scale(x))
data = data[data['in_smoke?'] == 1] # Cut down data to just fire days

# Drop NA values
data = data.dropna(subset=['zscore', 'zscore_pm'])
data = data.reset_index()

# Loop through the data, perform the linear regression on the values between PM total concentration
# and the elemental concentration.
lin_regress = []
for i in params: 
    fire_vals = data.reset_index().set_index(['State Code', 'County Code', 'Site Number', 'POC'])
    fire_vals = fire_vals[fire_vals['Parameter Name'] == i]
    
    # Do the linear regression on the PM2.5 and element data for each element and append to final variable
    slope, intercept, r_value, p_value, stderr = stats.linregress(fire_vals['zscore_pm'], fire_vals['zscore'])
    length = len(fire_vals)
    data_2 = [[i, slope, intercept, r_value, p_value, stderr, length]]
    lr = pd.DataFrame(data_2, columns = ['Parameter Name', 'Slope', 'Intercept', 'RVal', 'PVal', 'StdErr', 'Number'])
    lin_regress.append(lr)
    
    # Plot the data and line of best fit
    plt.rcParams['font.size']=14
    alavg = np.mean(fire_vals['zscore'])
    plt.axhline(y=0, color = 'k', linestyle ='-', linewidth=1)
    plt.plot(fire_vals['zscore_pm'], intercept + slope*fire_vals['zscore_pm'], 'b', label='fitted line')
    plt.scatter(fire_vals['zscore_pm'], fire_vals['zscore'], s=15, c='#1b9e77', label = 'Fire Days') #'#1b9e77')
    
    plt.rc('font', size=10)
    plt.xlabel('Normalized PM $_{2.5}$ Concentration') 
    plt.ylabel('Normalized '+i[:-8]+' Concentration') 
    #plt.legend()
    r_squared = r_value**2
    ax = plt.gca()
    plt.text(1,1.1, 'R$^2$ = %0.4f' % r_squared, color='k', horizontalalignment='right', verticalalignment='center', transform=ax.transAxes)
    plt.text(1,1.05, 'N = %i' % length, color='k', horizontalalignment='right', verticalalignment='center', transform=ax.transAxes)
    plt.savefig('C:\\Users\\KBoaggio\\OneDrive - Environmental Protection Agency (EPA)\\Wildfire data\\Manuscript figures\\PM regression plots\\robusttestnewnew_'+i+'_pm_11_4.png', bbox_inches='tight', dpi=300)
    plt.close()
    
pm_lin_regress = pd.concat(lin_regress)
pm_lin_regress.to_csv('PM25_linear_regression_results.csv')
