# -*- coding: utf-8 -*-
"""
Created on Mon Nov 29 11:11:40 2021

@author: KBOAGGIO
"""
import pandas as pd
import matplotlib.pyplot as plt
import os
os.chdir('C:\\Users\\KBoaggio\\OneDrive - Environmental Protection Agency (EPA)\\Wildfire data\\Final files for submission')
from itertools import cycle, islice
from functools import reduce
import functions


#%% Import and format the data

# Import linked speciation/smoke plume data
pm_spec = pd.read_csv('2006-2018_pm_speciation_labeled_joined_pm_11_3_21.csv')
pm_spec['Date'] = pd.to_datetime(pm_spec['Date'])
pm_spec = pm_spec.reset_index().set_index(['Date', 'State Code', 'County Code', 'Site Number', 'POC'])
pm_spec = pm_spec[~pm_spec.index.get_level_values(0).month.isin([1, 2, 3])] # Cut down data to April-December only
pm_spec['Arithmetic Mean'] = pm_spec['Arithmetic Mean'].astype(float) # Change data type for analysis

# Split the speciation data into fire and non-fire and create column for year
spec_fire_tot = pm_spec[(pm_spec['in_smoke?'] == 1)]
spec_no_fire_tot = pm_spec[pm_spec['in_smoke?'] != 1]
spec_fire_tot['Type'] = 'Fire'
spec_no_fire_tot['Type'] = 'No Fire'
spec_fire_tot['Year'] = pd.DatetimeIndex(spec_fire_tot.index.get_level_values('Date')).year
spec_no_fire_tot['Year'] = pd.DatetimeIndex(spec_no_fire_tot.index.get_level_values('Date')).year
pm_spec_added_col = pd.concat([spec_fire_tot, spec_no_fire_tot])

# Take average for each station separately for each year
fire_mean, nofire_mean, percent_diff, pd_avg, sm = functions.stations(spec_fire_tot, spec_no_fire_tot)

#%% Prep for Figures 6 and 7

fires17 = spec_fire_tot.reset_index().set_index(['Date','State Code', 'County Code', 'Site Number', 'POC'])
camp_fire_date = fires17.loc[('06-28-08'),] # Change for each fire date
camp_fire_date = camp_fire_date[camp_fire_date['Parameter Name'].str.contains("LC")]
camp_fire_date = camp_fire_date[['Parameter Name', 'Arithmetic Mean', 'Arithmetic Mean_pm']]

# Comment and uncomment the specific stations for each fire
# CSN
#camp_fire_fresno_c = camp_fire_date.loc[(6,19,11,5)]
camp_fire_AA = camp_fire_date.loc[6,67,6,5]
camp_fire_SJ = camp_fire_date.loc[6,85,5,5]
#camp_fire_mod = camp_fire_date.loc[6,99,5,5]
#camp_fire_chico = camp_fire_date.loc[6,7,8,5]
# IMPROVE
#camp_fire_fresno_i = camp_fire_date.loc[6,19,11,1]
camp_fire_PR = camp_fire_date.loc[6,41,2,1]
#camp_fire_pinnacles = camp_fire_date.loc[6,69,3,1]
#camp_fire_lassen = camp_fire_date.loc[6,89,3003,1]
#camp_fire_trinity = camp_fire_date.loc[6,105,9000,1]
#camp_fire_yosemite = camp_fire_date.loc[6,43,3,1]
#camp_fire_yosemite_2 = camp_fire_date.loc[6,43,3,2]
#camp_fire_lava = camp_fire_date.loc[6,93,5]

# Comment and uncomment the specific stations for renaming the columns
# CSN
#camp_fire_fresno = camp_fire_fresno_c.rename(columns = {"Arithmetic Mean":"Fresno (CSN)", "Arithmetic Mean_pm":"Fresno (CSN) PM"})
camp_fire_AA = camp_fire_AA.rename(columns = {"Arithmetic Mean":"Arden-Arcade", "Arithmetic Mean_pm":"Arden-Arcade PM"}) 
camp_fire_SJ = camp_fire_SJ.rename(columns = {"Arithmetic Mean":"San Jose", "Arithmetic Mean_pm":"San Jose PM"}) 
#camp_fire_mod = camp_fire_mod.rename(columns = {"Arithmetic Mean":"Modesto", "Arithmetic Mean_pm":"Modesto PM"}) 
#camp_fire_chico = camp_fire_chico.rename(columns = {'Arithmetic Mean':'Chico', "Arithmetic Mean_pm":"Chico PM"})
# IMPROVE
#camp_fire_fresno_2 = camp_fire_fresno_i.rename(columns = {"Arithmetic Mean":"Fresno (IMPROVE)", "Arithmetic Mean_pm":"Fresno (IMPROVE) PM"})  
camp_fire_PR = camp_fire_PR.rename(columns = {"Arithmetic Mean":"Point Reyes", "Arithmetic Mean_pm":"Point Reyes PM"}) 
#camp_fire_pinnacles = camp_fire_pinnacles.rename(columns = {"Arithmetic Mean":"Pinnacles", "Arithmetic Mean_pm":"Pinnacles PM"}) 
#camp_fire_lassen = camp_fire_lassen.rename(columns = {"Arithmetic Mean":"Lassen", "Arithmetic Mean_pm":"Lassen PM"}) 
#camp_fire_trinity = camp_fire_trinity.rename(columns = {"Arithmetic Mean":"Trinity", "Arithmetic Mean_pm":"Trinity PM"}) 
#camp_fire_yosemite = camp_fire_yosemite.rename(columns = {"Arithmetic Mean":"Yosemite", "Arithmetic Mean_pm":"Yosemite PM"}) 
#camp_fire_yosemite_2 = camp_fire_yosemite_2.rename(columns = {"Arithmetic Mean":"Yosemite (2)", "Arithmetic Mean_pm":"Yosemite (2 PM"}) 
#camp_fire_lava = camp_fire_lava.rename(columns = {"Arithmetic Mean":"Lava Beds", "Arithmetic Mean_pm":"Lava Beds PM"})


#%% Figures 6 and 7

# Change the stations below for each fire 
# Camp Fire: camp_fire_AA, camp_fire_PR, camp_fire_SJ, camp_fire_fresno, camp_fire_fresno_2, camp_fire_pinnacles, camp_fire_mod
# 2015 Fire: camp_fire_AA, camp_fire_SJ, camp_fire_fresno, camp_fire_fresno_2, camp_fire_yosemite, camp_fire_yosemite_2, camp_fire_lava
# Tubbs Fire: camp_fire_AA, camp_fire_PR, camp_fire_lassen, camp_fire_chico, camp_fire_trinity, camp_fire_lava
# Carr Fire: camp_fire_trinity, camp_fire_lassen, camp_fire_lava (camp_fire_chico)
study_fire = reduce(lambda x,y: pd.merge(x,y, on='Parameter Name', how='outer'), [camp_fire_AA, camp_fire_PR, camp_fire_SJ]) # Change based on lists above
study_fire = study_fire.reset_index().set_index(['Parameter Name'])
study_fire = study_fire.drop(['index'], axis=1)
r = [0,1,2,3] 
barWidth = 0.5

# Change spec list based on Figure 6 or 7
#spec_list_camp = ['Aluminum PM2.5 LC', 'Calcium PM2.5 LC', 'Chromium PM2.5 LC', 'Copper PM2.5 LC',  'Iron PM2.5 LC', 'Lead PM2.5 LC', 'Magnesium PM2.5 LC',  'Manganese PM2.5 LC', 'Nickel PM2.5 LC', 'Rubidium PM2.5 LC', 'Sodium PM2.5 LC', 'Strontium PM2.5 LC', 'Titanium PM2.5 LC', 'Vanadium PM2.5 LC', 'Zinc PM2.5 LC', 'Zirconium PM2.5 LC']
spec_list_camp = ['Arsenic PM2.5 LC', 'Chromium PM2.5 LC', 'Copper PM2.5 LC', 'Lead PM2.5 LC', 'Magnesium PM2.5 LC',  'Manganese PM2.5 LC', 'Nickel PM2.5 LC', 'Rubidium PM2.5 LC', 'Strontium PM2.5 LC', 'Titanium PM2.5 LC', 'Vanadium PM2.5 LC','Zirconium PM2.5 LC']
#labels_camp = ['Aluminum', 'Calcium', 'Chromium', 'Copper',  'Iron', 'Lead', 'Magnesium',  'Manganese', 'Nickel', 'Rubidium', 'Sodium', 'Strontium', 'Titanium', 'Vanadium', 'Zinc', 'Zirconium']
labels_camp = ['Arsenic', 'Chromium', 'Copper', 'Lead', 'Magnesium',  'Manganese', 'Nickel', 'Rubidium', 'Strontium', 'Titanium', 'Vanadium','Zirconium']


# Cut down data based on list of species
df_fire = study_fire.loc[spec_list_camp]
df_fire_spec = df_fire[df_fire.columns.drop(list(df_fire.filter(regex='PM')))]
df_fire_PM = df_fire.filter(regex='PM')

# Change colors list in order of the six events
#my_colors = list(islice(cycle(['dimgray', 'gainsboro', 'maroon','red','yellow','sandybrown','darkkhaki','peachpuff','yellowgreen','palegreen','limegreen','darkslategrey','indigo','dodgerblue','blue', 'blueviolet']), None, len(df_fire)))
my_colors = list(islice(cycle(['black', 'maroon','red','sandybrown','darkkhaki','peachpuff','yellowgreen','palegreen', 'darkslategrey','indigo','dodgerblue','blueviolet']), None, len(df_fire)))

plt.rc('font', size=20)
ax1 = df_fire_spec.T.plot(kind='bar', stacked=True, color=my_colors, figsize=[5,10])
ax2 = df_fire_PM.iloc[0].plot(secondary_y=True, color='k', marker='o')
ax2.set_ylabel('PM concentration ($\\mu$g/m$^3$)')
ax1.legend(loc='center left', bbox_to_anchor=(1.3, 0.5), labels=labels_camp)
ax1.set_xticklabels(df_fire_spec.columns)
ax1.set_ylabel('Concentration ($\\mu$g/m$^3$)')
ax1.set_ylim(-0.01, 0.25) # 0.25 for Figure 7, 1.75 for Figure 6
plt.setp(ax1.get_xticklabels(), rotation=45, ha="right", rotation_mode="anchor")

plt.savefig('06-26-08_newest_cut.png', bbox_inches='tight', dpi=300)


#%% 
import datetime as dt

pm_spec['Date Local'] = pd.to_datetime(pm_spec['Date Local'])
pm_spec['Date Local'] = pm_spec['Date Local'].dt.date
start_date = dt.date(2018,11,7) # 2020,9,7 11,8
end_date = dt.date(2018,11,20) # 2020,9,24 11,25
mask = (pm_spec['Date Local'] >= start_date) & (pm_spec['Date Local'] <= end_date)
camp_fire = pm_spec.loc[mask]

camp_fire = camp_fire[camp_fire['Parameter Name'] == 'Lead PM2.5 LC']







