# -*- coding: utf-8 -*-
"""
Created on Mon Nov 29 10:39:59 2021

@author: KBOAGGIO
"""
import pandas as pd
import os
import numpy as np

os.chdir('C:\\Users\\KBoaggio\\OneDrive - Environmental Protection Agency (EPA)\\Wildfire data')

#%% Count number of measurements of zero for Supplementary Table 2

def count(fire, no_fire):
    spec_fire_tot = fire.reset_index().set_index('Parameter Name')
    spec_no_fire_tot = no_fire.reset_index().set_index('Parameter Name')
    species = list(spec_fire_tot.index.get_level_values(0).unique()) # Get list of species names
    
    # Count the number of non-zero measurements
    nonzero = []
    for i in species:
        spec_fire = spec_fire_tot.loc[i]
        spec_no = spec_no_fire_tot.loc[i]
        spec_nonzero = pd.DataFrame()
        spec_nonzero['Non-zero fire days'] = [len(spec_fire[spec_fire['Arithmetic Mean'] != 0])]
        spec_nonzero['Non-zero total days'] = [len(spec_fire[spec_fire['Arithmetic Mean'] != 0]) + len(spec_no[spec_no['Arithmetic Mean'] != 0])]
        spec_nonzero['Total fire days'] = [len(spec_fire)]
        spec_nonzero['Total days'] = [len(spec_fire) + len(spec_no)]
        spec_nonzero['% fire days (total)'] = [(len(spec_fire)/(len(spec_fire)+len(spec_no)))*100]
        spec_nonzero['% non-zero fire days'] = [100*len(spec_fire[spec_fire['Arithmetic Mean'] != 0]) / (len(spec_fire[spec_fire['Arithmetic Mean'] != 0])+ len(spec_no[spec_no['Arithmetic Mean'] != 0]))]
        spec_nonzero['Parameter Name'] = [i]
        nonzero.append(spec_nonzero)
        
    non_zeros = pd.concat(nonzero) 
    return non_zeros

#%% Take average for each station separately for each year

def stations(spec_fire_tot, spec_no_fire_tot):
    spec_fire_tot = spec_fire_tot.reset_index().set_index(['State Code', 'County Code', 'Site Num', 'POC', 'Parameter Name','Year'])
    spec_no_fire_tot = spec_no_fire_tot.reset_index().set_index(['State Code', 'County Code', 'Site Num', 'POC', 'Parameter Name','Year'])
    
    # Take the average for the parameters across all stations each year
    spec_tot = spec_no_fire_tot
    station_mean = spec_no_fire_tot
    test_station = spec_tot.groupby(spec_tot.index)['Arithmetic Mean'].mean() # Take the average at each station, for each parameter and year
    station_mean.update(test_station)
    station_mean = station_mean.reset_index().set_index(['Parameter Name', 'Year'])
    station_mean_t = station_mean.groupby(station_mean.index)['Arithmetic Mean'].mean() # Take the averages of all the stations averages for each element and year
    station_mean.update(station_mean_t)
    station_mean = station_mean.reset_index().set_index(['State Code', 'County Code', 'Site Num', 'POC', 'Parameter Name','Year'])
    station_mean = station_mean[~station_mean.index.duplicated()]
    # The variable "station_mean" is now one value for each element and year, which is the average of the average concentrations at all stations 
    
    # Get the average on fire and non-fire days at each station, each year
    fire_mean = spec_fire_tot
    nofire_mean = spec_no_fire_tot 
    
     # Count number of fire and non-fire days and add a column for them
    fire_days_numb = pd.DataFrame(fire_mean.groupby(fire_mean.index)['Arithmetic Mean'].count(), index=fire_mean.index)
    nofire_days_numb =  pd.DataFrame(nofire_mean.groupby(nofire_mean.index)[['Arithmetic Mean']].count(), index=nofire_mean.index)
    fire_days_numb = fire_days_numb[~fire_days_numb.index.duplicated()]
    nofire_days_numb = nofire_days_numb[~nofire_days_numb.index.duplicated()]
    fire_mean['Number fire days'] = fire_days_numb
    fire_mean['Number non-fire days'] = nofire_days_numb
    nofire_mean['Number fire days'] = fire_days_numb
    nofire_mean['Number non-fire days'] = nofire_days_numb
    
    # Take the average at each station, for each parameter and year, for fire and non-fire days
    test_f = fire_mean.groupby(fire_mean.index)['Arithmetic Mean'].mean()
    test_nf = nofire_mean.groupby(nofire_mean.index)['Arithmetic Mean'].mean()
    fire_mean.update(test_f)
    nofire_mean.update(test_nf) 
    nofire_mean['Arithmetic Mean'] = nofire_mean['Arithmetic Mean'].replace(0, np.nan)
    nofire_mean['Arithmetic Mean'] = nofire_mean['Arithmetic Mean'].fillna(nofire_mean.groupby(nofire_mean.index)['Arithmetic Mean'].transform('min'))
    fire_mean = fire_mean[~fire_mean.index.duplicated()]
    nofire_mean = nofire_mean[~nofire_mean.index.duplicated()]
    # The variables "fire_mean" and "nofire_mean" are the mean values for each parameter/year/station  
    
    # Get the percent difference between fire and non-fire days at all stations for each parameter, each year
    # Also get the deviation from the station mean (fire and non-fire difference divided by station mean)
    spec_percent = pd.DataFrame(fire_mean['Arithmetic Mean'].subtract(nofire_mean['Arithmetic Mean'], axis='index')).dropna()
    spec_percent['Percentage'] = ((spec_percent.divide(nofire_mean['Arithmetic Mean'], axis='index')*100)) #.iloc[:,0]
    #spec_percent['Deviation'] = (spec_percent['Arithmetic Mean'].divide(station_mean['Arithmetic Mean'], axis='index')) #.dropna()
    spec_percent['Deviation'] = (spec_percent['Arithmetic Mean'].divide(nofire_mean['Arithmetic Mean'], axis='index')) #.dropna()
    spec_percent = spec_percent.dropna()
    spec_percent['Number fire days'] = nofire_mean['Number fire days']
    spec_percent['Number non-fire days'] = nofire_mean['Number non-fire days']
    # The variable "spec_percent" contains the difference between fire and non-fire averages across each parameter,
    # station, and year. It also contains this in percent difference and deviation from the station mean.
    
    # Take the average of the station differences and percentage differences for each parameter and year
    spec_percenty = spec_percent.reset_index().set_index(['Parameter Name', 'Year'])
    test_3 = spec_percenty.groupby(spec_percenty.index)['Arithmetic Mean'].apply(lambda x: x.mean())
    test_4 = spec_percenty.groupby(spec_percenty.index)['Percentage'].apply(lambda x: x.mean())
    test_5 = spec_percenty.groupby(spec_percenty.index)['Deviation'].apply(lambda x: x.mean())
    spec_percenty.update(test_3)
    spec_percenty.update(test_4)
    spec_percenty.update(test_5)
    spec_percenty = spec_percenty[~spec_percenty.index.duplicated()]
    # The variable "spec_percenty" contains the average of the percent, concentration differences, and
    # deviation across all stations for each parameter and year.
    
    return fire_mean, nofire_mean, spec_percent, spec_percenty, station_mean